@@ -1,12 +1,11 @@
 package XML::GrammarBase;
-$XML::GrammarBase::VERSION = '0.2.8';
+$XML::GrammarBase::VERSION = '0.2.9';
 use warnings;
 use strict;
 
 use 5.008;
 
-
-1;    # End of XML::GrammarBase
+1;
 
 __END__
 
@@ -21,7 +20,7 @@ specialized XML grammars.
 
 =head1 VERSION
 
-version 0.2.8
+version 0.2.9
 
 =head1 SYNOPSIS
 
