@@ -1,5 +1,5 @@
 package XML::GrammarBase::Role::DataDir;
-$XML::GrammarBase::Role::DataDir::VERSION = '0.2.8';
+$XML::GrammarBase::Role::DataDir::VERSION = '0.2.9';
 use strict;
 use warnings;
 
@@ -61,8 +61,7 @@ sub dist_path_slot
     return $self->dist_path( $self->$slot() );
 }
 
-
-1;    # End of XML::GrammarBase::RelaxNG::Validate
+1;
 
 __END__
 
@@ -76,7 +75,7 @@ XML::GrammarBase::Role::DataDir - provide the data_dir accessor.
 
 =head1 VERSION
 
-version 0.2.8
+version 0.2.9
 
 =head1 SYNOPSIS
 
