@@ -1,5 +1,5 @@
 package XML::GrammarBase::Role::RelaxNG;
-$XML::GrammarBase::Role::RelaxNG::VERSION = '0.2.8';
+$XML::GrammarBase::Role::RelaxNG::VERSION = '0.2.9';
 use strict;
 use warnings;
 
@@ -12,7 +12,7 @@ use XML::LibXML '2.0017';
 with('XML::GrammarBase::Role::DataDir');
 
 has 'rng_schema_basename' => ( isa => 'Str', is => 'rw' );
-has '_rng'                => (
+has '_rng' => (
     isa     => 'XML::LibXML::RelaxNG',
     is      => 'rw',
     default => sub { return shift->_calc_default_rng_schema; },
@@ -83,8 +83,7 @@ sub rng_validate_string
     return $self->rng_validate_dom($dom);
 }
 
-
-1;    # End of XML::GrammarBase::RelaxNG::Validate
+1;
 
 __END__
 
@@ -98,7 +97,7 @@ XML::GrammarBase::Role::RelaxNG - base class for a RelaxNG validator
 
 =head1 VERSION
 
-version 0.2.8
+version 0.2.9
 
 =head1 SYNOPSIS
 
