@@ -1,9 +1,8 @@
 package XML::GrammarBase::Role::XSLT;
-$XML::GrammarBase::Role::XSLT::VERSION = '0.2.8';
+$XML::GrammarBase::Role::XSLT::VERSION = '0.2.9';
 use strict;
 use warnings;
 
-
 use Package::Variant
     importing => [ 'MooX::Role' => ['late'], ],
     subs      => [qw(has with)];
@@ -36,9 +35,7 @@ sub make_variant
     return;
 }
 
-
-
-1;    # End of XML::GrammarBase::RelaxNG::Validate
+1;
 
 __END__
 
@@ -52,7 +49,7 @@ XML::GrammarBase::Role::XSLT - a parameterized role for XSLT conversions.
 
 =head1 VERSION
 
-version 0.2.8
+version 0.2.9
 
 =head1 SYNOPSIS
 
