@@ -1,5 +1,5 @@
 package XML::GrammarBase::Role::XSLT::Global;
-$XML::GrammarBase::Role::XSLT::Global::VERSION = '0.2.8';
+$XML::GrammarBase::Role::XSLT::Global::VERSION = '0.2.9';
 use strict;
 use warnings;
 
@@ -34,8 +34,7 @@ sub _calc_stylesheet
     my $style_doc =
         $self->_xml_parser()
         ->parse_file(
-        $self->dist_path_slot("to_${output_format}_xslt_transform_basename"),
-        );
+        $self->dist_path_slot("to_${output_format}_xslt_transform_basename"), );
 
     return $self->_xslt_parser->parse_stylesheet($style_doc);
 }
@@ -136,8 +135,7 @@ sub perform_xslt_translation
     confess "Unknown medium";
 }
 
-
-1;    # End of XML::GrammarBase::RelaxNG::Validate
+1;
 
 __END__
 
@@ -151,7 +149,7 @@ XML::GrammarBase::Role::XSLT::Global - a base, non-parameterised, role for an XS
 
 =head1 VERSION
 
-version 0.2.8
+version 0.2.9
 
 =head1 SYNOPSIS
 
